@@ -243,6 +243,11 @@ class sqlobj(object):
 	def add_frame(self, sheet_name, dataframe):
 		self.addr(sheet_name, dataframe)
 
+	def add_csv(self, filename):
+		if os.path.exists(filename):
+			tempdata = pd.read_csv(filename)
+			self.addr(filename.split('/')[-1].replace('.csv',''), tempdata)
+
 	def __iadd__(self, dataframe):
 		if isinstance(dataframe, pd.DataFrame):
 			self.add_frame("Addon", dataframe)
@@ -325,7 +330,7 @@ class sqlobj(object):
 	def tocsv(self, table_name):
 		table_data = self[table_name] if table_name in list(self.table_names()) else None
 		if table_data is not None:
-			table_data.to_csv(".{0}.csv".format(table_name))
+			table_data.to_csv("{0}.csv".format(table_name))
 
 	def drop_table(self, table_name, backup=True):
 		table_names = list(self.table_names())
